@@ -27,7 +27,7 @@ no warnings _disabled_warnings();
 use B::Hooks::AtRuntime 'after_runtime';
 use Import::Into;
 
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 
 sub import {
     my ( $class, %args ) = @_;
@@ -121,7 +121,7 @@ MooseX::Extended - Extend Moose with safe defaults and useful features
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
@@ -308,89 +308,12 @@ Excluding this will make the C<field> function unavailable.
 
 =head2 C<includes>
 
-Some experimental features are useful, but might not be quite what you want.
+Several I<optional> features of L<MooseX::Extended> make this module much more
+powerful. For example, to include try/catch and a C<method> keyword:
 
-By default, L<MooseX::Extended> tries to be relatively conservative. However,
-you might want to turn it up to 11. There are optional, B<EXPERIMENTAL>
-features you can use for this. They're turned by the C<includes> flag.
+        use MooseX::Extended includes => [ 'method', 'try' ];
 
-=over 4
-
-=item * C<multi>
-
-    use MooseX::Extended includes => [qw/multi/];
-
-    multi sub foo ($self, $x)      { ... }
-    multi sub foo ($self, $x, $y ) { ... }
-
-Allows you to redeclare a method (or subroutine) and the dispatch will use the number
-of arguments to determine which subroutine to use. Note that "slurpy" arguments such as
-arrays or hashes will take precedence over scalars:
-
-    multi sub foo ($self, @x) { ... }
-    multi sub foo ($self, $x) { ... } # will never be called
-
-Thus, the following probably doesn't do what you want.
-
-    package Foo {
-        use MooseX::Extended includes => [qw/multi/];
-
-        multi sub foo ($self, @bar) { return '@bar' }
-        multi sub foo ($self, $bar) { return '$bar' }
-    }
-
-    say +Foo->new->foo(1);
-    say +Foo->new->foo(1,2,3);
-
-Both of the above will print the string C<@bar>. The second definition of
-C<foo> is effectively lost.
-
-Only available on Perl v5.26.0 or higher. Requires L<Syntax::Keyword::MultiSub>.
-
-=item * C<async>
-
-    package My::Thing {
-        use MooseX::Extended
-        types    => [qw/Str/],
-        includes => ['async'];
-        use IO::Async::Loop;
-
-        field output => ( is => 'rw', isa => Str, default => '' );
-
-        async sub doit ( $self, @list ) {
-            my $loop = IO::Async::Loop->new;
-            $self->output('> ');
-            foreach my $item (@list) {
-                await $loop->delay_future( after => 0.01 );
-                $self->output( $self->output . "$item " );
-            }
-        }
-    }
-
-Allows you to write asynchronous code with C<async> and C<await>.
-
-Only available on Perl v5.26.0 or higher. Requires L<Future::AsyncAwait>.
-
-=item * C<try>
-
-    package My::Try {
-        use MooseX::Extended includes => [qw/try/];
-
-        sub reciprocal ( $self, $num ) {
-            try {
-                return 1 / $num;
-            }
-            catch {
-                croak "Could not calculate reciprocal of $num: $@";
-            }
-        }
-    }
-
-Allows you to use try/catch blocks, via L<Syntax::Keyword::Try>.
-
-Only available on Perl v5.24.0 or higher. Requires L<Syntax::Keyword::Try>.
-
-=back
+See L<MooseX::Extended::Manual::Includes> for more information.
 
 =head1 REDUCING BOILERPLATE
 
@@ -398,7 +321,7 @@ Let's say you've settled on the following feature set:
 
     use MooseX::Extended
         excludes => [qw/StrictConstructor carp/],
-        includes => [qw/multi/];
+        includes => [qw/method/];
 
 And you keep typing that over and over. We've removed a lot of boilerplate,
 but we've added different boilerplate. Instead, just create
